<?php

require_once 'base/FpaeventohEntityBase.php';


/**
 * FpaeventohEntity.
 *
 * @package Entity
 * @author  alessandrobartels
 */
class FpaeventohEntity extends FpaEventohEntityBase
{


    /**
     * Compatibiliza a referencia do item calculo (evento) em horas.
     *
     * @param float   $referencia     Valor da referencia.
     * @param integer $tipo_ref       Tipo de referencia.
     * @param float   $jornada_diaria Jornada diaria de trabalho do vinculo.
     *
     * @return float
     *
     * @author alessandrobartels
     */
    public static function compatibilizaReferenciaHoras($referencia, $tipo_ref, $jornada_diaria){

        switch($tipo_ref){
        case self::IDUNIDREFEREVEN_HORA:
            return $referencia;
            break;
        case self::IDUNIDREFEREVEN_DIA:
            return $referencia * $jornada_diaria;
            break;
        case self::IDUNIDREFEREVEN_HORA_MINUTO:
            return FPA::converteHoraDecimal($referencia);
            break;
        default:
            /* @todo chamar tk_show_message */
            $msg = 'Verifique o tipo de referencia: '.$tipo_ref;
            $msg .= ' Referencia:'.$referencia.' - '.get_called_class().'<br/>';
            //@todo MsgCalculo
            MsgCalculo::getInstance()->adicionaMensagem($msg);
            //tk_warning($msg);
        }

    }


    /**
     * Recebe dias e devolve dias ou horas com base no tipo de evento e na jornada.
     *
     * @param float $dias           Valor da referencia em dias.
     * @param float $jornada_diaria Jornada diaria de trabalho do vinculo.
     *
     * @return float
     *
     * @author alessandrobartels 29/08/2011
     */
    public function compatibilizaReferenciaDiasParaN($dias, $jornada_diaria){

        switch($this->getIdunidrefereven()){
        case self::IDUNIDREFEREVEN_DIA:
            return $dias;
            break;
        case self::IDUNIDREFEREVEN_HORA:
            $referencia = $dias * $jornada_diaria;
            // Como 30*7.33 não gera 220 exatos, fiz um tratamento que marreta a hora arredondada(220) BORBA 04/03/2013
            if ($referencia > 219.9 && $referencia < 220.01){
                $referencia = 220.0;
            } else if ($referencia > 109.9 && $referencia < 110.01){
                $referencia = 110.0;
            }
            return $referencia;
            break;
        default:
            /* @todo chamar tk_show_message */
            $msg = 'Verifique o tipo de referencia: '.$tipo_ref;
            $msg .= ' Referencia:'.$referencia.' - '.get_called_class().'<br/>';
            //@todo MsgCalculo
            MsgCalculo::getInstance()->adicionaMensagem($msg);
            //tk_warning($msg);
        }

    }


    /**
     * Compatibiliza a referencia do item calculo (evento) em dias.
     *
     * @param float   $referencia     Valor da referencia.
     * @param integer $tipo_ref       Tipo de referencia.
     * @param float   $jornada_diaria Jornada diaria de trabalho do vinculo.
     *
     * @return float
     *
     * @author alessandrobartels
     */
    public static function compatibilizaReferenciaDias($referencia, $tipo_ref, $jornada_diaria){
        switch($tipo_ref){
        case self::IDUNIDREFEREVEN_HORA:
            return $referencia / $jornada_diaria;
            break;
        case self::IDUNIDREFEREVEN_DIA:
            return $referencia;
            break;
        default:
            /* @todo chamar tk_show_message */
            $msg = 'Verifique o tipo de referencia: '.$tipo_ref;
            $msg .= ' Referencia:'.$referencia.' - '.get_called_class().'<br/>';
            //@todo MsgCalculo
            MsgCalculo::getInstance()->adicionaMensagem($msg);
            //tk_warning($msg);
        }
    }


    /**
     * Retorna instancia de FpaeventohEntity por mes de competencia.
     *
     * @param integer $nrEventom      Numero do evento mestre.
     * @param string  $mesCompetencia Mes de competencia.
     *
     * @return FpaeventohEntity
     *
     * @author alessandrobartels - 13/10/2011
     */
    public function retornaEventoHistoricoMesCompetencia($nrEventom, $mesCompetencia){
        return Fpaeventoh::retornaHistoricoPorCompetencia($nrEventom, $mesCompetencia);
    }


    /**
     * Retorna instancia de FpaeventohEntity por tipo de evento.
     *
     * @param string $idTipoEvento Tipo de evento mestre.
     *
     * @return FpaeventohEntity
     *
     * @author alessandrobartels - 13/10/2011
     */
    public function retornaMaximoOrdemImpressaoPorTipoEvento($idTipoEvento){
        return Fpaeventoh::retornaMaximoOrdemImpressaoPorTipoEvento($idTipoEvento);
    }

    /**
     * Retorna o ultimo evento historico.
     *
     * @param string $vr_link Valor do link.
     *
     * @return Fpaeventoh
     *
     * @author alessandrobartels
     */
    public static function retornaUltimoHistorico($vr_link){
        $vh= null;
        $vinculos_historico = self::getObjectsByWhere(
            'NREVENTOM = ?', array($vr_link)
        );

        if (empty($vinculos_historico) !== true) {
            $vh = end($vinculos_historico);
        } else {
            //@todo MsgCalculo
            MsgCalculo::getInstance()->adicionaMensagem('Evento '.$vr_link.' não cadastrado corretamente - Histórico');
            //tk_warning('Evento '.$vr_link.' nao cadastrado corretamente - EH');
        }


        return $vh;
    }

    /**
     * @param $nreventom
     *
     * @return mixed
     * @autor jorgefonseca
     */
    public static function getUltimoHistorico($nreventom)
    {
        $fpaeventoh = self::getEntitiesByWhere('NREVENTOM = ?', array($nreventom), 'NREVENTOH');
        return end($fpaeventoh);
    }

    /**
     * @param $nreventom
     * @param $idimpressevento
     * @param $cdintegraevento
     * @param $ideventodemonst
     * @param $idfaltas13resc
     * @param $idretrocedevent
     * @param $idzeraevenfecha
     * @param $idmediaevenferi
     * @param $dtmescompetenc
     * @param $nmeventoh
     *
     * @return FpaeventohEntity
     */
    public function insereEventoHistorico($nreventom, $idimpressevento, $cdintegraevento, $ideventodemonst,
                                          $idfaltas13resc, $idretrocedevent, $idzeraevenfecha, $idmediaevenferi,
                                          $dtmescompetenc, $nmeventoh)
    {
        $this->setNreventom($nreventom);
        $this->setIdimpressevento($idimpressevento);
        $this->setCdintegraevento($cdintegraevento);
        $this->setIdeventodemonst($ideventodemonst);
        $this->setIdfaltas13resc($idfaltas13resc);
        $this->setIdretrocedevent($idretrocedevent);
        $this->setIdzeraevenfecha($idzeraevenfecha);
        $this->setIdmediaevenferi($idmediaevenferi);
        $this->setDtmescompetenc($dtmescompetenc);
        $this->setNmeventoh($nmeventoh);
    }

}

